import com.j256.ormlite.dao.Dao;
import com.j256.ormlite.dao.DaoManager;
import com.j256.ormlite.jdbc.JdbcConnectionSource;
import com.j256.ormlite.support.ConnectionSource;

import java.util.Scanner;

public class AccountApp {
    // we are using a MySQl database
    private final static String DATABASE_URL = "jdbc:mysql://localhost:3306/orm_lab?useUnicode=true";

    private Dao<Account, Integer> accountDao;

    Scanner in = new Scanner(System.in);

    public static void main(String[] args) throws Exception {
        // turn our static method into an instance of Main
        new AccountApp().doMain(args);
    }

    private void doMain(String[] args) throws Exception {
        ConnectionSource connectionSource = null;
        try {

            // create our data-source for the database
            connectionSource = new JdbcConnectionSource(DATABASE_URL, "root", "password");
            // setup our  DAOs

            setupDao(connectionSource);
            // read, write and delete some data
            processData();

            System.out.println("\n\nIt seems to have worked\n\n");
        } finally {
            // destroy the data source which should close underlying connections
            if (connectionSource != null) {
                connectionSource.close();
            }
        }
    }

    /**
     * Read and write some example data.
     */
    private void processData() throws Exception {
        // create an instance of Account
        boolean bank = true;
        while(bank){
            System.out.println("Welcome to our Bank how may we help\n press 1 to create account, 2 to update password, 3 to read from database, 4 to delete account, 5 to exit bank");
            int response = in.nextInt();
            switch (response) {
                case 1:
                    createAccount();
                    break;
                case 2:
                    updateTable();
                    break;
                case 3:
                    readFromTable();
                    break;
                case 4:
                    System.out.println("Enter id to delete");
                    int deleteId = in.nextInt();
                    accountDao.deleteById(deleteId);
                    break;
                case 5:
                    System.out.println("Thank you");
                    bank = false;
                    break;
            }

        }
    }

    private void createAccount() throws Exception{
        System.out.println("Enter your name");
        String name = in.next();
        System.out.println("Enter your password");
        String password = in.next();
        Account account = new Account(name);

        // persist the account object to the database
        accountDao.create(account);

        int id = account.getId();
        System.out.println(id);
        // assign a password
        account.setPassword(password);
        // update the database after changing the object
        accountDao.update(account);
    }

    private void updateTable() throws Exception{
        System.out.println("Enter id whose password you want to change");
        int id = in.nextInt();
        System.out.println("Enter new password");
        String newPassword = in.next();
        Account acc = accountDao.queryForId(id);
        //acc.setName();
        acc.setPassword(newPassword);
        accountDao.update(acc);
    }

    private void readFromTable() throws Exception{
        System.out.println("Enter id you want to show");
        int id = in.nextInt();
        Account acc = accountDao.queryForId(id);
        System.out.println("The name with this id is " + acc.getName());
    }

    /**
     * Setup our  DAOs
     */

    private void setupDao(ConnectionSource connectionSource) throws Exception {

        accountDao = DaoManager.createDao(connectionSource, Account.class);

    }
}

